const canvas = document.getElementById('drawing');
const ctx = canvas.getContext('2d');

const sparks = [];

let color = 0;
let numOfInteractiveSparks = 8;
let numOfSparks = 60;
let d1 = 100;
let d2 = 90;
let delay = 150;
let v1 = 10;
let v2 = 10;
let r = 9;

const computerMouse = {
  x: null,
  y: null
}

 setInterval(function(){
    computerMouse.x = undefined;
    computerMouse.y = undefined;
 }, 3500);  

canvas.addEventListener('mousemove', function(event){
  computerMouse.x = event.x;
  computerMouse.y = event.y;
  for(let i = 0; i < numOfInteractiveSparks; i++){
    sparks.push(new Spark());
  } 
});

class Spark {
  constructor(){
    this.x = computerMouse.x;
    this.y = computerMouse.y;
    if(computerMouse.x == undefined && computerMouse.y == undefined){
      this.x = Math.random() * 800;
      this.y = Math.random() * 800;
    }    
    this.radius = Math.random() * r + 1;
    this.vX = Math.random() * v1 - 1;
    this.vY = Math.random() * v2 - 1;
    this.colorChange = 'hsl(' + color + ', 100%, 50%)';
  }
  update(){
    if(computerMouse.x == undefined && computerMouse.y == undefined){
      this.vX = Math.random() * 1;
      this.vY = Math.random() * 1;
      if(this.radius > 0.2){
        this.radius -= 0.05;
      }
    }
    this.x += this.vX;
    this.y += this.vY;
    if(this.radius > 0.2 && computerMouse.x != undefined && computerMouse.y != undefined) this.radius -= 0.1;
  }
  draw(){
    ctx.fillStyle = this.colorChange;
    ctx.beginPath();
    ctx.arc(this.x, this.y, this.radius, 0, Math.PI * 2);
    ctx.fill();
  }  
}

function createConstellation(){
  for(let i = 0; i < sparks.length; i++){
    sparks[i].draw();
    sparks[i].update();
    for(let j = i; j < sparks.length; j++){
      const dx = sparks[i].x - sparks[j].x;
      const dy = sparks[i].y - sparks[j].y;
      const d = Math.sqrt(dx*dx + dy*dy);
      if(computerMouse.x == undefined && computerMouse.y == undefined){
        if(d < d1){
          ctx.beginPath();
          ctx.strokeStyle = sparks[i].colorChange;
          ctx.lineWidth = sparks[i].radius/20;
          ctx.moveTo(sparks[i].x, sparks[i].y);
          ctx.lineTo(sparks[j].x, sparks[j].y);
          ctx.stroke();
        }        
      }
      else{
        if(d < d2){
          ctx.beginPath();
          ctx.strokeStyle = sparks[i].colorChange;
          ctx.lineWidth = sparks[i].radius/20;
          ctx.moveTo(sparks[i].x, sparks[i].y);
          ctx.lineTo(sparks[j].x, sparks[j].y);
          ctx.stroke();
        }
      }     
    }    
    if(sparks[i].radius <= 0.3){
      sparks.splice(i, 1);
      i--;
    }

  }
}

function init(){
  for(let i = 0; i < numOfSparks; i++){
    sparks.push(new Spark());
  } 
}

let cnt = 0;

function animation(){
  ctx.clearRect(0, 0, 800, 800);
  cnt++;
  if(cnt >= delay && computerMouse.x == undefined && computerMouse.y == undefined){
    init();
    cnt = 0;
  }
  createConstellation();
  color++;
  requestAnimationFrame(animation);
}

animation();